@@ -95,10 +95,19 @@ progress() {
   echo >&2 " --- ${TPUT_DIM}${TPUT_BOLD}${*}${TPUT_RESET} --- "
 }
 
+check_for_curl() {
+  if [ -z "${curl}" ]; then
+    curl="$(PATH="${PATH}:/opt/netdata/bin" command -v curl 2>/dev/null && true)"
+  fi
+}
+
 get() {
   url="${1}"
-  if command -v curl > /dev/null 2>&1; then
-    curl -q -o - -sSL --connect-timeout 10 --retry 3 "${url}"
+
+  check_for_curl
+
+  if [ -n "${curl}" ]; then
+    "${curl}" -q -o - -sSL --connect-timeout 10 --retry 3 "${url}"
   elif command -v wget > /dev/null 2>&1; then
     wget -T 15 -O - "${url}"
   else
@@ -112,8 +121,10 @@ download_file() {
   name="${3}"
   opt="${4}"
 
-  if command -v curl > /dev/null 2>&1; then
-    run curl -q -sSL --connect-timeout 10 --retry 3 --output "${dest}" "${url}"
+  check_for_curl
+
+  if [ -n "${curl}" ]; then
+    run "${curl}" -q -sSL --connect-timeout 10 --retry 3 --output "${dest}" "${url}"
   elif command -v wget > /dev/null 2>&1; then
     run wget -T 15 -O "${dest}" "${url}"
   else
@@ -180,6 +191,133 @@ netdata_banner() {
   echo >&2
 }
 
+# -----------------------------------------------------------------------------
+# Feature management and configuration commands
+
+enable_feature() {
+  NETDATA_CMAKE_OPTIONS="$(echo "${NETDATA_CMAKE_OPTIONS}" | sed -e "s/-DENABLE_${1}=Off[[:space:]]*//g" -e "s/-DENABLE_${1}=On[[:space:]]*//g")"
+  if [ "${2}" -eq 1 ]; then
+    NETDATA_CMAKE_OPTIONS="$(echo "${NETDATA_CMAKE_OPTIONS}" | sed "s/$/ -DENABLE_${1}=On/")"
+  else
+    NETDATA_CMAKE_OPTIONS="$(echo "${NETDATA_CMAKE_OPTIONS}" | sed "s/$/ -DENABLE_${1}=Off/")"
+  fi
+}
+
+check_for_module() {
+  if [ -z "${pkgconf}" ]; then
+    pkgconf="$(command -v pkgconf 2>/dev/null)"
+    [ -z "${pkgconf}" ] && pkgconf="$(command -v pkg-config 2>/dev/null)"
+    [ -z "${pkgconf}" ] && fatal "Unable to find a usable pkgconf/pkg-config command, cannot build Netdata." I0013
+  fi
+
+  "${pkgconf}" "${1}"
+  return "${?}"
+}
+
+check_for_feature() {
+  feature_name="${1}"
+  feature_state="${2}"
+  shift 2
+  feature_modules="${*}"
+
+  if [ -z "${feature_state}" ]; then
+    # shellcheck disable=SC2086
+    if check_for_module ${feature_modules}; then
+      enable_feature "${feature_name}" 1
+    else
+      enable_feature "${feature_name}" 0
+    fi
+  else
+    enable_feature "${feature_name}" "${feature_state}"
+  fi
+}
+
+prepare_cmake_options() {
+  NETDATA_CMAKE_OPTIONS="-S ./ -B ${NETDATA_BUILD_DIR} ${CMAKE_OPTS} ${NETDATA_PREFIX+-DCMAKE_INSTALL_PREFIX="${NETDATA_PREFIX}"} ${NETDATA_USER:+-DNETDATA_USER=${NETDATA_USER}} ${NETDATA_CMAKE_OPTIONS} "
+
+  NEED_OLD_CXX=0
+
+  if [ "${FORCE_LEGACY_CXX:-0}" -eq 1 ]; then
+    NEED_OLD_CXX=1
+  else
+    if command -v gcc >/dev/null 2>&1; then
+      if [ "$(gcc --version | head -n 1 | sed 's/(.*) //' | cut -f 2 -d ' ' | cut -f 1 -d '.')" -lt 5 ]; then
+        NEED_OLD_CXX=1
+      fi
+    fi
+
+    if command -v clang >/dev/null 2>&1; then
+      if [ "$(clang --version | head -n 1 | cut -f 3 -d ' ' | cut -f 1 -d '.')" -lt 4 ]; then
+        NEED_OLD_CXX=1
+      fi
+    fi
+  fi
+
+  if [ "${NEED_OLD_CXX}" -eq 1 ]; then
+    NETDATA_CMAKE_OPTIONS="${NETDATA_CMAKE_OPTIONS} -DUSE_CXX_11=On"
+  fi
+
+  if [ "${ENABLE_GO:-1}" -eq 1 ]; then
+    enable_feature PLUGIN_GO 1
+  else
+    enable_feature PLUGIN_GO 0
+  fi
+
+  if [ "${USE_SYSTEM_PROTOBUF:-0}" -eq 1 ]; then
+    enable_feature BUNDLED_PROTOBUF 0
+  else
+    enable_feature BUNDLED_PROTOBUF 1
+  fi
+
+  if [ -z "${ENABLE_SYSTEMD_JOURNAL}" ]; then
+      if check_for_module libsystemd; then
+          if check_for_module libelogind; then
+              ENABLE_SYSTEMD_JOURNAL=0
+          else
+              ENABLE_SYSTEMD_JOURNAL=1
+          fi
+      else
+          ENABLE_SYSTEMD_JOURNAL=0
+      fi
+  fi
+
+  enable_feature PLUGIN_SYSTEMD_JOURNAL "${ENABLE_SYSTEMD_JOURNAL}"
+
+  if command -v cups-config >/dev/null 2>&1 || check_for_module libcups || check_for_module cups; then
+    ENABLE_CUPS=1
+  else
+    ENABLE_CUPS=0
+  fi
+
+  enable_feature PLUGIN_CUPS "${ENABLE_CUPS}"
+
+  IS_LINUX=0
+  [ "$(uname -s)" = "Linux" ] && IS_LINUX=1
+  enable_feature PLUGIN_DEBUGFS "${IS_LINUX}"
+  enable_feature PLUGIN_PERF "${IS_LINUX}"
+  enable_feature PLUGIN_SLABINFO "${IS_LINUX}"
+  enable_feature PLUGIN_CGROUP_NETWORK "${IS_LINUX}"
+  enable_feature PLUGIN_LOCAL_LISTENERS "${IS_LINUX}"
+  enable_feature PLUGIN_NETWORK_VIEWER "${IS_LINUX}"
+  enable_feature PLUGIN_EBPF "${ENABLE_EBPF:-0}"
+  enable_feature PLUGIN_LOGS_MANAGEMENT "${ENABLE_LOGS_MANAGEMENT:-0}"
+  enable_feature LOGS_MANAGEMENT_TESTS "${ENABLE_LOGS_MANAGEMENT_TESTS:-0}"
+
+  enable_feature ACLK "${ENABLE_CLOUD:-1}"
+  enable_feature CLOUD "${ENABLE_CLOUD:-1}"
+  enable_feature BUNDLED_JSONC "${NETDATA_BUILD_JSON_C:-0}"
+  enable_feature DBENGINE "${ENABLE_DBENGINE:-1}"
+  enable_feature H2O "${ENABLE_H2O:-1}"
+  enable_feature ML "${NETDATA_ENABLE_ML:-1}"
+  enable_feature PLUGIN_APPS "${ENABLE_APPS:-1}"
+
+  check_for_feature EXPORTER_PROMETHEUS_REMOTE_WRITE "${EXPORTER_PROMETHEUS}" snappy
+  check_for_feature EXPORTER_MONGODB "${EXPORTER_MONGODB}" libmongoc-1.0
+  check_for_feature PLUGIN_FREEIPMI "${ENABLE_FREEIPMI}" libipmimonitoring
+  check_for_feature PLUGIN_NFACCT "${ENABLE_NFACCT}" libnetfilter_acct libnml
+  check_for_feature PLUGIN_XENSTAT "${ENABLE_XENSTAT}" xenstat xenlight
+}
+
 # -----------------------------------------------------------------------------
 # portable service command
 
@@ -400,7 +538,7 @@ get_group(){
   if command -v getent > /dev/null 2>&1; then
     getent group "${1:-""}"
   else
-    cat /etc/group | grep "^${1}:" 
+    grep "^${1}:" /etc/group
   fi
 }
 
@@ -452,45 +590,6 @@ get_systemd_service_dir() {
   fi
 }
 
-install_non_systemd_init() {
-  [ "${UID}" != 0 ] && return 1
-  key="$(get_os_key)"
-
-  if [ -d /etc/init.d ] && [ ! -f /etc/init.d/netdata ]; then
-    if expr "${key}" : "^(gentoo|alpine).*"; then
-      echo >&2 "Installing OpenRC init file..."
-      run cp system/netdata-openrc /etc/init.d/netdata &&
-        run chmod 755 /etc/init.d/netdata &&
-        run rc-update add netdata default &&
-        return 0
-
-    elif expr "${key}" : "^devuan*" || [ "${key}" = "debian-7" ] || [ "${key}" = "ubuntu-12.04" ] || [ "${key}" = "ubuntu-14.04" ]; then
-      echo >&2 "Installing LSB init file..."
-      run cp system/netdata-lsb /etc/init.d/netdata &&
-        run chmod 755 /etc/init.d/netdata &&
-        run update-rc.d netdata defaults &&
-        run update-rc.d netdata enable &&
-        return 0
-    elif expr "${key}" : "^(amzn-201[5678]|ol|CentOS release 6|Red Hat Enterprise Linux Server release 6|Scientific Linux CERN SLC release 6|CloudLinux Server release 6).*"; then
-      echo >&2 "Installing init.d file..."
-      run cp system/netdata-init-d /etc/init.d/netdata &&
-        run chmod 755 /etc/init.d/netdata &&
-        run chkconfig netdata on &&
-        return 0
-    else
-      warning "Could not determine what type of init script to install on this system."
-      return 1
-    fi
-  elif [ -f /etc/init.d/netdata ]; then
-    echo >&2 "file '/etc/init.d/netdata' already exists."
-    return 0
-  else
-    warning "Could not determine what type of init script to install on this system."
-  fi
-
-  return 1
-}
-
 run_install_service_script() {
   if [ -z "${tmpdir}" ]; then
     tmpdir="${TMPDIR:-/tmp}"
@@ -554,90 +653,7 @@ install_netdata_service() {
     if [ -x "${NETDATA_PREFIX}/usr/libexec/netdata/install-service.sh" ]; then
       run_install_service_script && return 0
     else
-      # This is used by netdata-installer.sh
-      # shellcheck disable=SC2034
-      NETDATA_STOP_CMD="netdatacli shutdown-agent"
-
-      NETDATA_START_CMD="netdata"
-      NETDATA_INSTALLER_START_CMD=""
-
-      uname="$(uname 2> /dev/null)"
-
-      if [ "${uname}" = "Darwin" ]; then
-        if [ -f "/Library/LaunchDaemons/com.github.netdata.plist" ]; then
-          echo >&2 "file '/Library/LaunchDaemons/com.github.netdata.plist' already exists."
-          return 0
-        else
-          echo >&2 "Installing MacOS X plist file..."
-          # This is used by netdata-installer.sh
-          # shellcheck disable=SC2034
-          run cp system/netdata.plist /Library/LaunchDaemons/com.github.netdata.plist &&
-            run launchctl load /Library/LaunchDaemons/com.github.netdata.plist &&
-            NETDATA_START_CMD="launchctl start com.github.netdata" &&
-            NETDATA_STOP_CMD="launchctl stop com.github.netdata"
-          return 0
-        fi
-
-      elif [ "${uname}" = "FreeBSD" ]; then
-        # This is used by netdata-installer.sh
-        # shellcheck disable=SC2034
-        run cp system/netdata-freebsd /etc/rc.d/netdata && NETDATA_START_CMD="service netdata start" &&
-          NETDATA_STOP_CMD="service netdata stop" &&
-          NETDATA_INSTALLER_START_CMD="service netdata onestart" &&
-          myret=$?
-
-        echo >&2 "Note: To explicitly enable netdata automatic start, set 'netdata_enable' to 'YES' in /etc/rc.conf"
-        echo >&2 ""
-
-        return ${myret}
-
-      elif issystemd; then
-        # systemd is running on this system
-        NETDATA_START_CMD="systemctl start netdata"
-        # This is used by netdata-installer.sh
-        # shellcheck disable=SC2034
-        NETDATA_STOP_CMD="systemctl stop netdata"
-        NETDATA_INSTALLER_START_CMD="${NETDATA_START_CMD}"
-
-        SYSTEMD_DIRECTORY="$(get_systemd_service_dir)"
-
-        if [ "${SYSTEMD_DIRECTORY}x" != "x" ]; then
-          ENABLE_NETDATA_IF_PREVIOUSLY_ENABLED="run systemctl enable netdata"
-          IS_NETDATA_ENABLED="$(systemctl is-enabled netdata 2> /dev/null || echo "Netdata not there")"
-          if [ "${IS_NETDATA_ENABLED}" = "disabled" ]; then
-            echo >&2 "Netdata was there and disabled, make sure we don't re-enable it ourselves"
-            ENABLE_NETDATA_IF_PREVIOUSLY_ENABLED="true"
-          fi
-
-          echo >&2 "Installing systemd service..."
-          run cp system/netdata.service "${SYSTEMD_DIRECTORY}/netdata.service" &&
-            run systemctl daemon-reload &&
-            ${ENABLE_NETDATA_IF_PREVIOUSLY_ENABLED} &&
-            return 0
-        else
-          warning "Could not find a systemd service directory, unable to install Netdata systemd service."
-        fi
-      else
-        install_non_systemd_init
-        ret=$?
-
-        if [ ${ret} -eq 0 ]; then
-          if [ -n "${service_cmd}" ]; then
-            NETDATA_START_CMD="service netdata start"
-            # This is used by netdata-installer.sh
-            # shellcheck disable=SC2034
-            NETDATA_STOP_CMD="service netdata stop"
-          elif [ -n "${rcservice_cmd}" ]; then
-            NETDATA_START_CMD="rc-service netdata start"
-            # This is used by netdata-installer.sh
-            # shellcheck disable=SC2034
-            NETDATA_STOP_CMD="rc-service netdata stop"
-          fi
-          NETDATA_INSTALLER_START_CMD="${NETDATA_START_CMD}"
-        fi
-
-        return ${ret}
-      fi
+      warning "Could not find service install script, not installing Netdata as a system service."
     fi
   fi
 
@@ -834,10 +850,12 @@ restart_netdata() {
 # install netdata logrotate
 
 install_netdata_logrotate() {
+  src="${NETDATA_PREFIX}/usr/lib/netdata/system/logrotate/netdata"
+
   if [ "${UID}" -eq 0 ]; then
     if [ -d /etc/logrotate.d ]; then
       if [ ! -f /etc/logrotate.d/netdata ]; then
-        run cp system/netdata.logrotate /etc/logrotate.d/netdata
+        run cp "${src}" /etc/logrotate.d/netdata
       fi
 
       if [ -f /etc/logrotate.d/netdata ]; then
@@ -873,8 +891,10 @@ create_netdata_conf() {
     export http_proxy=
     export https_proxy=
 
-    if command -v curl 1> /dev/null 2>&1; then
-      run curl -sSL --connect-timeout 10 --retry 3 "${url}" > "${path}.new"
+    check_for_curl
+
+    if [ -n "${curl}" ]; then
+      run "${curl}" -sSL --connect-timeout 10 --retry 3 "${url}" > "${path}.new"
     elif command -v wget 1> /dev/null 2>&1; then
       run wget -T 15 -O - "${url}" > "${path}.new"
     fi
@@ -890,8 +910,13 @@ create_netdata_conf() {
   fi
 
   if [ -z "$url" ]; then
-    echo "# netdata can generate its own config which is available at 'http://<netdata_ip>/netdata.conf'" > "${path}"
-    echo "# You can download it with command like: 'wget -O ${path} http://localhost:19999/netdata.conf'" >> "${path}"
+    cat << EOF > "${path}"
+# netdata can generate its own config which is available at 'http://<IP>:19999/netdata.conf'
+# You can download it using:
+#    curl -o ${path} http://localhost:19999/netdata.conf
+# or
+#    wget -O ${path} http://localhost:19999/netdata.conf
+EOF
   fi
 
 }
@@ -903,33 +928,41 @@ portable_add_user() {
   [ -z "${homedir}" ] && homedir="/tmp"
 
   # Check if user exists
-  if cut -d ':' -f 1 < /etc/passwd | grep "^${username}$" 1> /dev/null 2>&1; then
-    echo >&2 "User '${username}' already exists."
-    return 0
+  if command -v getent > /dev/null 2>&1; then
+    if getent passwd "${username}" > /dev/null 2>&1; then
+        echo >&2 "User '${username}' already exists."
+        return 0
+    fi
+  elif command -v dscl > /dev/null 2>&1; then
+    if dscl . read /Users/"${username}" >/dev/null 2>&1; then
+      echo >&2 "User '${username}' already exists."
+      return 0
+    fi
+  else
+    if cut -d ':' -f 1 < /etc/passwd | grep "^${username}$" 1> /dev/null 2>&1; then
+        echo >&2 "User '${username}' already exists."
+        return 0
+    fi
   fi
 
   echo >&2 "Adding ${username} user account with home ${homedir} ..."
 
   nologin="$(command -v nologin || echo '/bin/false')"
 
-  # Linux
   if command -v useradd 1> /dev/null 2>&1; then
     run useradd -r -g "${username}" -c "${username}" -s "${nologin}" --no-create-home -d "${homedir}" "${username}" && return 0
-  fi
-
-  # FreeBSD
-  if command -v pw 1> /dev/null 2>&1; then
+  elif command -v pw 1> /dev/null 2>&1; then
     run pw useradd "${username}" -d "${homedir}" -g "${username}" -s "${nologin}" && return 0
-  fi
-
-  # BusyBox
-  if command -v adduser 1> /dev/null 2>&1; then
+  elif command -v adduser 1> /dev/null 2>&1; then
     run adduser -h "${homedir}" -s "${nologin}" -D -G "${username}" "${username}" && return 0
-  fi
-
-  # mac OS
-  if command -v sysadminctl 1> /dev/null 2>&1; then
-    run sysadminctl -addUser "${username}" && return 0
+  elif command -v sysadminctl 1> /dev/null 2>&1; then
+    gid=$(dscl . read /Groups/"${username}" 2>/dev/null | grep PrimaryGroupID | grep -Eo "[0-9]+")
+    if run sysadminctl -addUser "${username}" -shell /usr/bin/false -home /var/empty -GID "$gid"; then
+      # FIXME: I think the proper solution is to create a role account:
+      # -roleAccount + name starting with _ and UID in 200-400 range.
+      run dscl . create /Users/"${username}" IsHidden 1
+      return 0
+    fi
   fi
 
   warning "Failed to add ${username} user account!"
@@ -951,20 +984,11 @@ portable_add_group() {
   # Linux
   if command -v groupadd 1> /dev/null 2>&1; then
     run groupadd -r "${groupname}" && return 0
-  fi
-
-  # FreeBSD
-  if command -v pw 1> /dev/null 2>&1; then
+  elif command -v pw 1> /dev/null 2>&1; then
     run pw groupadd "${groupname}" && return 0
-  fi
-
-  # BusyBox
-  if command -v addgroup 1> /dev/null 2>&1; then
+  elif command -v addgroup 1> /dev/null 2>&1; then
     run addgroup "${groupname}" && return 0
-  fi
-
-  # mac OS
-  if command -v dseditgroup 1> /dev/null 2>&1; then
+  elif command -v dseditgroup 1> /dev/null 2>&1; then
     dseditgroup -o create "${groupname}" && return 0
   fi
 
@@ -995,20 +1019,11 @@ portable_add_user_to_group() {
     # Linux
     if command -v usermod 1> /dev/null 2>&1; then
       run usermod -a -G "${groupname}" "${username}" && return 0
-    fi
-
-    # FreeBSD
-    if command -v pw 1> /dev/null 2>&1; then
+    elif command -v pw 1> /dev/null 2>&1; then
       run pw groupmod "${groupname}" -m "${username}" && return 0
-    fi
-
-    # BusyBox
-    if command -v addgroup 1> /dev/null 2>&1; then
+    elif command -v addgroup 1> /dev/null 2>&1; then
       run addgroup "${username}" "${groupname}" && return 0
-    fi
-
-    # mac OS
-    if command -v dseditgroup 1> /dev/null 2>&1; then
+    elif command -v dseditgroup 1> /dev/null 2>&1; then
       dseditgroup -u "${username}" "${groupname}" && return 0
     fi
 
@@ -1062,9 +1077,11 @@ install_netdata_updater() {
     cat "${NETDATA_SOURCE_DIR}/packaging/installer/netdata-updater.sh" > "${NETDATA_PREFIX}/usr/libexec/netdata/netdata-updater.sh" || return 1
   fi
 
-  if issystemd && [ -n "$(get_systemd_service_dir)" ]; then
-    cat "${NETDATA_SOURCE_DIR}/system/netdata-updater.timer" > "$(get_systemd_service_dir)/netdata-updater.timer"
-    cat "${NETDATA_SOURCE_DIR}/system/netdata-updater.service" > "$(get_systemd_service_dir)/netdata-updater.service"
+  # these files are installed by cmake
+  libsysdir="${NETDATA_PREFIX}/usr/lib/netdata/system/systemd/"
+  if [ -d "${libsysdir}" ] && issystemd && [ -n "$(get_systemd_service_dir)" ]; then
+    cat "${libsysdir}/netdata-updater.timer" > "$(get_systemd_service_dir)/netdata-updater.timer"
+    cat "${libsysdir}/netdata-updater.service" > "$(get_systemd_service_dir)/netdata-updater.service"
   fi
 
   sed -i -e "s|THIS_SHOULD_BE_REPLACED_BY_INSTALLER_SCRIPT|${NETDATA_USER_CONFIG_DIR}/.environment|" "${NETDATA_PREFIX}/usr/libexec/netdata/netdata-updater.sh" || return 1
